#! /bin/bash
#   n900crack.sh
#Middlesex University
#Author: Krystian Majda M00221109
#email: niervol@gmail.com or km857@live.mdx.ac.uk
#Date: 18 April 2011
#This bash script is a deliverable of the final year project, CCM3422.
#Project superviser: Dr Jonathan Loo
#Second superviser: Dr Robert Colson


#directories and variables
crackdir="/home/user"
driverdir="/home/user/MyDocs/wl1251-maemo/binary/compat-wireless/"
scanprefix="scan"
scanfile=$scanprefix"-01.csv"
networklist=networks.txt

#killing any processes left
sudo killall -q airodump-ng aircrack-ng aireplay-ng

#removing no longer needed files
cd $crackdir
rm -f handshake.txt $networklist replay*.cap arp-request.cap replay_dec*.xor replay*.cap *.netxml *.csv
#it doesn't delete password file (ap-name.txt) and ap-name.cap files as they may contain handshake or plenty of IVs

#unload the drivers
cd $driverdir
sudo ./unload.sh >>/dev/null 2>&1
sleep 2

exit
#end
